summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:01:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-04 14:01:21 -0600
commitb3ff2ac060e73fe76f377c499907003cc7378a51 (patch)
tree0517ee3513bd9c72cdb0bc872b67695473f1f3a9 /src
parent577ac5a23791dae4503e26ab46a3f7a0ba393c7a (diff)
downloadgwenview-b3ff2ac060e73fe76f377c499907003cc7378a51.tar.gz
gwenview-b3ff2ac060e73fe76f377c499907003cc7378a51.zip
Rename KIcon to enhance compatibility with KDE4
Diffstat (limited to 'src')
-rw-r--r--src/app/bookmarkdialogbase.ui2
-rw-r--r--src/gvcore/deletedialog.cpp2
-rw-r--r--src/gvcore/externaltooldialogbase.ui2
-rw-r--r--src/gvcore/filedetailview.cpp4
-rw-r--r--src/gvcore/filedetailviewitem.cpp2
-rw-r--r--src/gvcore/filethumbnailview.cpp16
-rw-r--r--src/gvcore/filethumbnailview.h2
-rw-r--r--src/gvcore/filethumbnailviewitem.cpp2
-rw-r--r--src/gvcore/thumbnailloadjob.cpp2
9 files changed, 17 insertions, 17 deletions
diff --git a/src/app/bookmarkdialogbase.ui b/src/app/bookmarkdialogbase.ui
index 08ccea2..2dc0524 100644
--- a/src/app/bookmarkdialogbase.ui
+++ b/src/app/bookmarkdialogbase.ui
@@ -70,7 +70,7 @@
<string>Icon:</string>
</property>
</widget>
- <widget class="KIconButton" row="0" column="1">
+ <widget class="TDEIconButton" row="0" column="1">
<property name="name">
<cstring>mIcon</cstring>
</property>
diff --git a/src/gvcore/deletedialog.cpp b/src/gvcore/deletedialog.cpp
index f2faca6..e5e443f 100644
--- a/src/gvcore/deletedialog.cpp
+++ b/src/gvcore/deletedialog.cpp
@@ -98,7 +98,7 @@ void DeleteDialog::updateUI()
fileCount);
iconName = "trashcan_full";
}
- TQPixmap icon = TDEGlobal::iconLoader()->loadIcon(iconName, KIcon::NoGroup, KIcon::SizeMedium);
+ TQPixmap icon = TDEGlobal::iconLoader()->loadIcon(iconName, TDEIcon::NoGroup, TDEIcon::SizeMedium);
m_widget->ddDeleteText->setText(msg);
m_widget->ddWarningIcon->setPixmap(icon);
diff --git a/src/gvcore/externaltooldialogbase.ui b/src/gvcore/externaltooldialogbase.ui
index 03cbe33..1b684df 100644
--- a/src/gvcore/externaltooldialogbase.ui
+++ b/src/gvcore/externaltooldialogbase.ui
@@ -159,7 +159,7 @@
<property name="name">
<cstring>unnamed</cstring>
</property>
- <widget class="KIconButton" row="0" column="3" rowspan="2" colspan="1">
+ <widget class="TDEIconButton" row="0" column="3" rowspan="2" colspan="1">
<property name="name">
<cstring>mIconButton</cstring>
</property>
diff --git a/src/gvcore/filedetailview.cpp b/src/gvcore/filedetailview.cpp
index 6d2dbb1..0dbb45d 100644
--- a/src/gvcore/filedetailview.cpp
+++ b/src/gvcore/filedetailview.cpp
@@ -124,7 +124,7 @@ FileDetailView::FileDetailView(TQWidget *parent, const char *name)
setDropVisualizer(false);
setDropHighlighter(false);
- int size = IconSize(KIcon::Small);
+ int size = IconSize(TDEIcon::Small);
mShownItemUnselectedPixmap = createShownItemPixmap(size, colorGroup().highlight());
mShownItemSelectedPixmap = createShownItemPixmap(size, colorGroup().highlightedText());
}
@@ -248,7 +248,7 @@ void FileDetailView::updateView( bool b )
TQListViewItemIterator it( (TQListView*)this );
for ( ; it.current(); ++it ) {
FileDetailViewItem *item=static_cast<FileDetailViewItem *>(it.current());
- item->setPixmap( 0, item->fileInfo()->pixmap(KIcon::SizeSmall) );
+ item->setPixmap( 0, item->fileInfo()->pixmap(TDEIcon::SizeSmall) );
}
}
diff --git a/src/gvcore/filedetailviewitem.cpp b/src/gvcore/filedetailviewitem.cpp
index 8342d77..98e6148 100644
--- a/src/gvcore/filedetailviewitem.cpp
+++ b/src/gvcore/filedetailviewitem.cpp
@@ -36,7 +36,7 @@ namespace Gwenview {
void FileDetailViewItem::init()
{
time_t time = TimeUtils::getTime(inf);
- setPixmap( COL_NAME, inf->pixmap(KIcon::SizeSmall));
+ setPixmap( COL_NAME, inf->pixmap(TDEIcon::SizeSmall));
setText( COL_NAME, inf->text() );
setText( COL_SIZE, TDEGlobal::locale()->formatNumber( inf->size(), 0));
diff --git a/src/gvcore/filethumbnailview.h b/src/gvcore/filethumbnailview.h
index 5f6ab83..28bc5f4 100644
--- a/src/gvcore/filethumbnailview.h
+++ b/src/gvcore/filethumbnailview.h
@@ -45,7 +45,7 @@ typedef TQPtrList<KFileItem> KFileItemList;
namespace Gwenview {
class FileThumbnailViewItem;
-class LIBGWENVIEW_EXPORT FileThumbnailView : public KIconView, public FileViewBase {
+class LIBGWENVIEW_EXPORT FileThumbnailView : public TDEIconView, public FileViewBase {
Q_OBJECT
friend class FileThumbnailViewItem;
diff --git a/src/gvcore/filethumbnailviewitem.cpp b/src/gvcore/filethumbnailviewitem.cpp
index 7c86bbe..548c3b8 100644
--- a/src/gvcore/filethumbnailviewitem.cpp
+++ b/src/gvcore/filethumbnailviewitem.cpp
@@ -1,7 +1,7 @@
// vim: set tabstop=4 shiftwidth=4 noexpandtab:
/* Gwenview - A simple image viewer for TDE
Copyright 2000-2004 Aurélien Gâteau
- This class is based on the KIconViewItem class from KDE libs.
+ This class is based on the TDEIconViewItem class from KDE libs.
Original copyright follows.
*/
/* This file is part of the KDE libraries
diff --git a/src/gvcore/thumbnailloadjob.cpp b/src/gvcore/thumbnailloadjob.cpp
index 61ed836..79acd44 100644
--- a/src/gvcore/thumbnailloadjob.cpp
+++ b/src/gvcore/thumbnailloadjob.cpp
@@ -379,7 +379,7 @@ ThumbnailLoadJob::ThumbnailLoadJob(const TQValueVector<const KFileItem*>* items,
LOG("");
mBrokenPixmap=TDEGlobal::iconLoader()->loadIcon("file_broken",
- KIcon::NoGroup, ThumbnailSize::MIN);
+ TDEIcon::NoGroup, ThumbnailSize::MIN);
// Look for images and store the items in our todo list
Q_ASSERT(!items->empty());
diff --git a/src/gvcore/filethumbnailview.cpp b/src/gvcore/filethumbnailview.cpp
index 387c497..ddff849 100644
--- a/src/gvcore/filethumbnailview.cpp
+++ b/src/gvcore/filethumbnailview.cpp
@@ -160,7 +160,7 @@ static FileThumbnailViewItem* viewItem(const FileThumbnailView* view, const KFil
FileThumbnailView::FileThumbnailView(TQWidget* parent)
-: KIconView(parent), FileViewBase()
+: TDEIconView(parent), FileViewBase()
{
d=new Private;
d->mUpdateThumbnailsOnNextShow=false;
@@ -183,10 +183,10 @@ FileThumbnailView::FileThumbnailView(TQWidget* parent)
setSpacing(0);
setAcceptDrops(true);
// We can't use KIconView::Execute mode because in this mode the current
// item is unselected after being clicked, so we use KIconView::Select mode
// and emit the execute() signal with slotClicked() ourself.
- setMode(KIconView::Select);
+ setMode(TDEIconView::Select);
connect(this, TQT_SIGNAL(clicked(TQIconViewItem*)),
this, TQT_SLOT(slotClicked(TQIconViewItem*)) );
connect(this, TQT_SIGNAL(doubleClicked(TQIconViewItem*)),
@@ -565,7 +565,7 @@ void FileThumbnailView::setSorting(TQDir::SortSpec spec) {
if (iconItem) setSortingKey(iconItem, item);
}
- KIconView::sort(! (spec & TQDir::Reversed) );
+ TDEIconView::sort(! (spec & TQDir::Reversed) );
}
//--------------------------------------------------------------------------
@@ -584,7 +584,7 @@ void FileThumbnailView::slotDropped(TQDropEvent* event) {
void FileThumbnailView::showEvent(TQShowEvent* event) {
- KIconView::showEvent(event);
+ TDEIconView::showEvent(event);
if (!d->mUpdateThumbnailsOnNextShow) return;
d->mUpdateThumbnailsOnNextShow=false;
@@ -724,10 +724,10 @@ void FileThumbnailView::keyPressEvent( TQKeyEvent* e ) {
if( e->key() != Key_Left
&& e->key() != Key_Right
&& e->key() != Key_Up
- && e->key() != Key_Down ) return KIconView::keyPressEvent( e );
+ && e->key() != Key_Down ) return TDEIconView::keyPressEvent( e );
TQIconViewItem* current = currentItem();
- KIconView::keyPressEvent( e );
+ TDEIconView::keyPressEvent( e );
TQIconViewItem* next = NULL;
if( current != currentItem() && currentItem() != NULL ) { // it actually moved
switch( e->key()) {
@@ -183,10 +183,10 @@ FileThumbnailView::FileThumbnailView(TQWidget* parent)
setSpacing(0);
setAcceptDrops(true);
- // We can't use KIconView::Execute mode because in this mode the current
- // item is unselected after being clicked, so we use KIconView::Select mode
+ // We can't use TDEIconView::Execute mode because in this mode the current
+ // item is unselected after being clicked, so we use TDEIconView::Select mode
// and emit the execute() signal with slotClicked() ourself.